==> resh-5.3.0.6-py3-none-any.whl: resh/utils/tools.py <==
import os
import subprocess
import time

from dali import address

from resh.utils import errors, const


class StrByte(dict):
    def __init__(self, bts):
        hex_val = ''.join(hex(b)[2:].rjust(2, '0') for b in bts).upper()
        int_val = int.from_bytes(bts, 'big')
        bin_val = bin(int_val)[2:].rjust(len(bts) * 8, '0')
        super(StrByte, self).__init__(hex=hex_val, dec=int_val, bin=bin_val)


def bits_indexes(byte, start_from=0) -> list:
    """
    Преобразует битовую маску в массив взведённых битов
    :type byte: int
    :param start_from: Индекс ненулевого бита запишется как i+start_from
    :type start_from: int
    """
    result = []
    _b = bin(byte)[2:]
    for ch in range(0, 8):
        if len(_b) > ch:
            if _b[-(ch+1)] == '1':
                result.append(ch+start_from)
        else:
            break
    return result


def bytes2str(scope: (list, bytes, bytearray, tuple), separator: str = ' ', typing=lambda o: hex(o)[2:].rjust(2, '0')) -> str:
    return separator.join(str(typing(i)) for i in scope)


def to_bytes(*scope):
    return bytes.fromhex(bytes2str(scope))


def write_file(file_name, data, executable=False):
    if not os.path.exists(os.path.dirname(file_name)):
        os.mkdir(os.path.dirname(file_name))
    with open(file_name, 'w') as file:
        file.write(data)
    if executable:
        os.chmod(file_name, 493)


def sys(command):
    p = subprocess.Popen(command.split(' '), stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    while p.poll() is None:
        time.sleep(0.1)
    return p.returncode


def parse_module(m_str) -> int:
    try:
        module = int(m_str)
        if module not in range(0, 32):
            raise
        return module
    except (IndexError, ValueError):
        raise errors.ModuleAddressError()


def parse_channel(ch_str) -> int:
    try:
        channel = int(ch_str)
        if channel not in range(1, 9):
            raise
        return channel
    except:
        raise errors.ChannelAddressError()


def parse_address(addr_str) -> address.Address:
    try:
        if addr_str:
            addr_str = addr_str.lower()
            if addr_str[0] == 'd':
                return address.Short(int(addr_str[1:]))
            elif addr_str[0] == 'g':
                return address.Group(int(addr_str[1:]))
            elif addr_str == 'b':
                return address.Broadcast()
            elif addr_str == 'bu':
                return address.BroadcastUnaddressed()
    except:
        raise errors.DeviceAddressError()

    raise errors.DeviceAddressError()


def parse_instance(instance_str) -> address.Instance:
    try:
        if instance_str:
            instance_str = instance_str.lower()
            if instance_str[0] == 'i':
                if instance_str[1] == 't':
                    return address.InstanceType(int(instance_str[2:]))
                elif instance_str[1] == 'n':
                    return address.InstanceNumber(int(instance_str[2:]))
                elif instance_str[1] == 'g':
                    return address.InstanceGroup(int(instance_str[2:]))
                elif instance_str[1] == 'b':
                    return address.InstanceBroadcast()
                else:
                    raise
            elif instance_str[0] == 'f':
                raise errors.CustomError(
                    f'Feature instances not supported! Use "Instance" types (I{instance_str[1:].upper()})')
            else:
                raise errors.InstanceAddressError()
    except errors.CustomError as ex:
        raise ex
    except:
        raise errors.InstanceAddressError()
    

def parse_domain(domain) -> str:
    if domain in (const.DALI, const.DALI2, const.SYS, const.EVENT):
        return domain

    raise errors.BadParameter('%s is not a domain' % domain)


def pack_instance(inst: address.Instance) -> str:
    if isinstance(inst, address.InstanceNumber):
        return f'IN{inst._value}'
    elif isinstance(inst, address.InstanceType):
        return f'IT{inst._value}'
    elif isinstance(inst, address.InstanceGroup):
        return f'IG{inst._value}'
    elif isinstance(inst, address.InstanceBroadcast):
        return 'IB'
    elif isinstance(inst, address.FeatureInstanceType):
        return f'FT{inst._value}'
    elif isinstance(inst, address.FeatureInstanceGroup):
        return f'FG{inst._value}'
    elif isinstance(inst, address.FeatureInstanceNumber):
        return f'FN{inst._value}'
    elif isinstance(inst, address.FeatureDevice):
        return f'FD{inst._value}'
    elif isinstance(inst, address.FeatureInstanceBroadcast):
        return f'FB'
    return 'X3'


def pack_address(addr: address.Address) -> str:
    if isinstance(addr, address.Short):
        return f'D{addr.address}'
    elif isinstance(addr, address.Group):
        return f'G{addr.group}'
    elif isinstance(addr, address.Broadcast):
        return 'B'
    elif isinstance(addr, address.BroadcastUnaddressed):
        return 'BU'
    return 'X3'

==> resh-5.5.0.95-py3-none-any.whl: resh/utils/tools.py <==
import os
import subprocess
import time

from dali import address

from resh.utils import errors, const
from resh.utils.errors import BadParameter


class StrByte(dict):
    def __init__(self, bts):
        hex_val = ''.join(hex(b)[2:].rjust(2, '0') for b in bts).upper()
        int_val = int.from_bytes(bts, 'big')
        bin_val = bin(int_val)[2:].rjust(len(bts) * 8, '0')
        super(StrByte, self).__init__(hex=hex_val, dec=int_val, bin=bin_val)


def bits_indexes(byte, start_from=0) -> list:
    """
    Преобразует битовую маску в массив взведённых битов
    :type byte: int
    :param start_from: Индекс ненулевого бита запишется как i+start_from
    :type start_from: int
    """
    result = []
    _b = bin(byte)[2:]
    for ch in range(0, 8):
        if len(_b) > ch:
            if _b[-(ch + 1)] == '1':
                result.append(ch + start_from)
        else:
            break
    return result


def get_bit(val: int, bit: int) -> bool:
    """
    Получает значение бита (True/False) в числе (массиве байт)
    """
    _mask = 1 << bit
    if bit > 32:
        _res = bool((val + 1) & _mask)
    else:
        _res = bool(val & _mask)
    return _res


def get_bits(val: int, from_bit: int, to_bit: int) -> int:
    """
    Возвращает число, полученное цепочкой битов в исходном числе
    """
    if from_bit > to_bit:
        raise BadParameter('Начальная позиция должна быть меньше конечной!')  # incorrect parameters

    _value = 0
    _i = 0
    for _bit in range(from_bit, to_bit + 1):
        _val = get_bit(val, _bit)
        _value += (_val << _i)
        _i += 1
    return _value


def numbers2mask(nums: list) -> int:
    _result = 0
    for _n in nums:
        if int(_n) in range(0, 9):
            if int(_n) > 0:
                _result += 1 << (int(_n) - 1)
            else:
                _result = 0
        else:
            raise BadParameter('Требуется число в диапазоне 0..8')
    return _result


def bytes2str(scope: (list, bytes, bytearray, tuple), separator: str = ' ',
              typing=lambda o: hex(o)[2:].rjust(2, '0')) -> str:
    return separator.join(str(typing(i)) for i in scope)


def to_bytes(*scope):
    return bytes.fromhex(bytes2str(scope))


def write_file(file_name, data, executable=False):
    if not os.path.exists(os.path.dirname(file_name)):
        os.mkdir(os.path.dirname(file_name))
    with open(file_name, 'w') as file:
        file.write(data)
    if executable:
        os.chmod(file_name, 493)


def sys(command):
    p = subprocess.Popen(command.split(' '), stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    while p.poll() is None:
        time.sleep(0.1)
    return p.returncode


def parse_module(m_str) -> int:
    try:
        module = int(m_str)
        if module not in range(0, 32):
            raise
        return module
    except (IndexError, ValueError):
        raise errors.ModuleAddressError()


def parse_channel(ch_str) -> int:
    try:
        channel = int(ch_str)
        if channel not in range(1, 9):
            raise
        return channel
    except:
        raise errors.ChannelAddressError()


def parse_address(addr_str) -> address.Address:
    try:
        if addr_str:
            addr_str = addr_str.lower()
            if addr_str[0] == 'd':
                return address.Short(int(addr_str[1:]))
            elif addr_str[0] == 'g':
                return address.Group(int(addr_str[1:]))
            elif addr_str == 'b':
                return address.Broadcast()
            elif addr_str == 'bu':
                return address.BroadcastUnaddressed()
    except:
        raise errors.DeviceAddressError()

    raise errors.DeviceAddressError()


def parse_instance(instance_str) -> address.Instance:
    try:
        if instance_str:
            instance_str = instance_str.lower()
            if instance_str[0] == 'i':
                if instance_str[1] == 't':
                    return address.InstanceType(int(instance_str[2:]))
                elif instance_str[1] == 'n':
                    return address.InstanceNumber(int(instance_str[2:]))
                elif instance_str[1] == 'g':
                    return address.InstanceGroup(int(instance_str[2:]))
                elif instance_str[1] == 'b':
                    return address.InstanceBroadcast()
                else:
                    raise
            elif instance_str[0] == 'f':
                raise errors.CustomError(
                    f'Feature instances not supported! Use "Instance" types (I{instance_str[1:].upper()})')
            else:
                raise errors.InstanceAddressError()
    except errors.CustomError as ex:
        raise ex
    except:
        raise errors.InstanceAddressError()


def parse_domain(domain) -> str:
    if domain in (const.DALI, const.DALI2, const.SYS, const.EVENT):
        return domain

    raise errors.BadParameter('%s is not a domain' % domain)


def _parse_address(address_str: str, prefix: str):
    try:
        if address_str:
            address_str = address_str.lower()
            if address_str[0] == prefix[0]:
                return int(address_str[1])
            else:
                raise errors.BadParameter()
    except:
        raise errors.BadParameter()

    raise errors.BadParameter()


def parse_relay(relay_str: str) -> int:
    try:
        return _parse_address(relay_str, 'r')
    except errors.BadParameter:
        raise errors.BadParameter(f'"{relay_str}" некорректный номер реле')
    except Exception:
        raise errors.BadParameter(f'"{relay_str}" некорректный номер реле')


def parse_group(group_str: str) -> int:
    try:
        return _parse_address(group_str, 'g')
    except errors.BadParameter:
        raise errors.BadParameter(f'"{group_str}" некорректный номер группы')
    except Exception:
        raise errors.BadParameter(f'"{group_str}" некорректный номер группы')


def pack_instance(inst: address.Instance) -> str:
    if isinstance(inst, address.InstanceNumber):
        return f'IN{inst._value}'
    elif isinstance(inst, address.InstanceType):
        return f'IT{inst._value}'
    elif isinstance(inst, address.InstanceGroup):
        return f'IG{inst._value}'
    elif isinstance(inst, address.InstanceBroadcast):
        return 'IB'
    elif isinstance(inst, address.FeatureInstanceType):
        return f'FT{inst._value}'
    elif isinstance(inst, address.FeatureInstanceGroup):
        return f'FG{inst._value}'
    elif isinstance(inst, address.FeatureInstanceNumber):
        return f'FN{inst._value}'
    elif isinstance(inst, address.FeatureDevice):
        return f'FD{inst._value}'
    elif isinstance(inst, address.FeatureInstanceBroadcast):
        return f'FB'
    return 'X3'


def pack_address(addr: address.Address) -> str:
    if isinstance(addr, address.Short):
        return f'D{addr.address}'
    elif isinstance(addr, address.Group):
        return f'G{addr.group}'
    elif isinstance(addr, address.Broadcast):
        return 'B'
    elif isinstance(addr, address.BroadcastUnaddressed):
        return 'BU'
    return 'X3'


def byte_array_to_ascii_str(byte_array, reverse_order=False):
    byte_array = byte_array[::-1] if reverse_order else byte_array
    try:
        return byte_array.decode('ascii')
    except UnicodeDecodeError:
        return  ''.join([chr(_byte) for _byte in byte_array])
